@@ -6,12 +6,14 @@ import (
 	"fmt"
 	"net/url"
 	"os"
+	"sort"
 	"strconv"
 	"strings"
 	"time"
 
 	"github.com/crowdsecurity/crowdsec/pkg/apiclient"
 	"github.com/crowdsecurity/crowdsec/pkg/cwversion"
+	"github.com/crowdsecurity/crowdsec/pkg/database"
 	"github.com/crowdsecurity/crowdsec/pkg/models"
 	"github.com/go-openapi/strfmt"
 	"github.com/olekukonko/tablewriter"
@@ -178,12 +180,16 @@ func DisplayOneAlert(alert *models.Alert, withDetail bool) error {
 				fmt.Printf("\n- Date: %s\n", *event.Timestamp)
 				table = tablewriter.NewWriter(os.Stdout)
 				table.SetHeader([]string{"Key", "Value"})
+				sort.Slice(event.Meta, func(i, j int) bool {
+					return event.Meta[i].Key < event.Meta[j].Key
+				})
 				for _, meta := range event.Meta {
 					table.Append([]string{
 						meta.Key,
 						meta.Value,
 					})
 				}
+
 				table.Render() // Send output
 			}
 		}
@@ -194,11 +200,15 @@ func DisplayOneAlert(alert *models.Alert, withDetail bool) error {
 func NewAlertsCmd() *cobra.Command {
 	/* ---- ALERTS COMMAND */
 	var cmdAlerts = &cobra.Command{
-		Use:   "alerts [action]",
-		Short: "Manage alerts",
-		Args:  cobra.MinimumNArgs(1),
+		Use:               "alerts [action]",
+		Short:             "Manage alerts",
+		Args:              cobra.MinimumNArgs(1),
+		DisableAutoGenTag: true,
 		PersistentPreRun: func(cmd *cobra.Command, args []string) {
 			var err error
+			if err := csConfig.LoadAPIClient(); err != nil {
+				log.Fatalf("loading api client: %s", err.Error())
+			}
 			if csConfig.API.Client == nil {
 				log.Fatalln("There is no configuration on 'api_client:'")
 			}
@@ -243,6 +253,7 @@ cscli alerts list --ip 1.2.3.4
 cscli alerts list --range 1.2.3.0/24
 cscli alerts list -s crowdsecurity/ssh-bf
 cscli alerts list --type ban`,
+		DisableAutoGenTag: true,
 		Run: func(cmd *cobra.Command, args []string) {
 			var err error
 
@@ -345,7 +356,8 @@ cscli alerts list --type ban`,
 		Example: `cscli alerts delete --ip 1.2.3.4
 cscli alerts delete --range 1.2.3.0/24
 cscli alerts delete -s crowdsecurity/ssh-bf"`,
-		Args: cobra.ExactArgs(0),
+		DisableAutoGenTag: true,
+		Args:              cobra.ExactArgs(0),
 		PreRun: func(cmd *cobra.Command, args []string) {
 			if AlertDeleteAll {
 				return
@@ -389,7 +401,8 @@ cscli alerts delete -s crowdsecurity/ssh-bf"`,
 					alertDeleteFilter.Contains = new(bool)
 				}
 			} else {
-				alertDeleteFilter = apiclient.AlertsDeleteOpts{}
+				limit := 0
+				alertDeleteFilter = apiclient.AlertsDeleteOpts{Limit: &limit}
 			}
 			alerts, _, err := Client.Alerts.Delete(context.Background(), alertDeleteFilter)
 			if err != nil {
@@ -412,9 +425,10 @@ cscli alerts delete -s crowdsecurity/ssh-bf"`,
 
 	var details bool
 	var cmdAlertsInspect = &cobra.Command{
-		Use:     "inspect <alert_id>",
-		Short:   `Show info about an alert`,
-		Example: `cscli alerts inspect 123`,
+		Use:               `inspect "alert_id"`,
+		Short:             `Show info about an alert`,
+		Example:           `cscli alerts inspect 123`,
+		DisableAutoGenTag: true,
 		Run: func(cmd *cobra.Command, args []string) {
 			if len(args) == 0 {
 				_ = cmd.Help()
@@ -456,5 +470,40 @@ cscli alerts delete -s crowdsecurity/ssh-bf"`,
 
 	cmdAlerts.AddCommand(cmdAlertsInspect)
 
+	var maxItems int
+	var maxAge string
+	var cmdAlertsFlush = &cobra.Command{
+		Use: `flush`,
+		Short: `Flush alerts
+/!\ This command can be used only on the same machine than the local API`,
+		Example:           `cscli alerts flush --max-items 1000 --max-age 7d`,
+		DisableAutoGenTag: true,
+		Run: func(cmd *cobra.Command, args []string) {
+			var err error
+			if err := csConfig.LoadAPIServer(); err != nil || csConfig.DisableAPI {
+				log.Fatal("Local API is disabled, please run this command on the local API machine")
+			}
+			if err := csConfig.LoadDBConfig(); err != nil {
+				log.Fatalf(err.Error())
+			}
+			dbClient, err = database.NewClient(csConfig.DbConfig)
+			if err != nil {
+				log.Fatalf("unable to create new database client: %s", err)
+			}
+			log.Info("Flushing alerts. !! This may take a long time !!")
+			err = dbClient.FlushAlerts(maxAge, maxItems)
+			if err != nil {
+				log.Fatalf("unable to flush alerts: %s", err)
+			}
+			log.Info("Alerts flushed")
+		},
+	}
+
+	cmdAlertsFlush.Flags().SortFlags = false
+	cmdAlertsFlush.Flags().IntVar(&maxItems, "max-items", 5000, "Maximum number of alert items to keep in the database")
+	cmdAlertsFlush.Flags().StringVar(&maxAge, "max-age", "7d", "Maximum age of alert items to keep in the database")
+
+	cmdAlerts.AddCommand(cmdAlertsFlush)
+
 	return cmdAlerts
 }
