@@ -63,6 +63,11 @@ func manageCliDecisionAlerts(ip *string, ipRange *string, scope *string, value *
 		*scope = types.Ip
 	case "range":
 		*scope = types.Range
+	case "country":
+		*scope = types.Country
+	case "as":
+		*scope = types.AS
+
 	}
 	return nil
 }
@@ -71,23 +76,25 @@ func setHubBranch() error {
 	/*
 		if no branch has been specified in flags for the hub, then use the one corresponding to crowdsec version
 	*/
-
 	if cwhub.HubBranch == "" {
 		latest, err := cwversion.Latest()
 		if err != nil {
 			cwhub.HubBranch = "master"
 			return err
 		}
-
-		if cwversion.Version == latest {
+		csVersion := cwversion.VersionStrip()
+		if csVersion == latest {
 			cwhub.HubBranch = "master"
-		} else if semver.Compare(cwversion.Version, latest) == 1 { // if current version is greater than the latest we are in pre-release
-			log.Debugf("Your current crowdsec version seems to be a pre-release (%s)", cwversion.Version)
+		} else if semver.Compare(csVersion, latest) == 1 { // if current version is greater than the latest we are in pre-release
+			log.Debugf("Your current crowdsec version seems to be a pre-release (%s)", csVersion)
+			cwhub.HubBranch = "master"
+		} else if csVersion == "" {
+			log.Warningf("Crowdsec version is '', using master branch for the hub")
 			cwhub.HubBranch = "master"
 		} else {
-			log.Warnf("Crowdsec is not the latest version. Current version is '%s' and latest version is '%s'. Please update it!", cwversion.Version, latest)
+			log.Warnf("Crowdsec is not the latest version. Current version is '%s' and the latest stable version is '%s'. Please update it!", csVersion, latest)
 			log.Warnf("As a result, you will not be able to use parsers/scenarios/collections added to Crowdsec Hub after CrowdSec %s", latest)
-			cwhub.HubBranch = cwversion.Version
+			cwhub.HubBranch = csVersion
 		}
 		log.Debugf("Using branch '%s' for the hub", cwhub.HubBranch)
 	}
@@ -124,8 +131,12 @@ func ListItem(itemType string, args []string) {
 		}
 		fmt.Printf("%s", string(x))
 	} else if csConfig.Cscli.Output == "raw" {
+		fmt.Printf("name,status,version,description\n")
 		for _, v := range hubStatus {
-			fmt.Printf("%s %s\n", v["name"], v["description"])
+			if v["local_version"] == "" {
+				v["local_version"] = "n/a"
+			}
+			fmt.Printf("%s,%s,%s,%s\n", v["name"], v["status"], v["local_version"], v["description"])
 		}
 	}
 }
@@ -133,7 +144,7 @@ func ListItem(itemType string, args []string) {
 func InstallItem(name string, obtype string, force bool) {
 	it := cwhub.GetItem(obtype, name)
 	if it == nil {
-		log.Fatalf("unable to retrive item : %s", name)
+		log.Fatalf("unable to retrieve item : %s", name)
 	}
 	item := *it
 	if downloadOnly && item.Downloaded && item.UpToDate {
@@ -142,18 +153,18 @@ func InstallItem(name string, obtype string, force bool) {
 			return
 		}
 	}
-	item, err := cwhub.DownloadLatest(csConfig.Cscli, item, force)
+	item, err := cwhub.DownloadLatest(csConfig.Hub, item, force, false)
 	if err != nil {
 		log.Fatalf("error while downloading %s : %v", item.Name, err)
 	}
 	cwhub.AddItem(obtype, item)
 	if downloadOnly {
-		log.Infof("Downloaded %s to %s", item.Name, csConfig.Cscli.HubDir+"/"+item.RemotePath)
+		log.Infof("Downloaded %s to %s", item.Name, csConfig.Hub.HubDir+"/"+item.RemotePath)
 		return
 	}
-	item, err = cwhub.EnableItem(csConfig.Cscli, item)
+	item, err = cwhub.EnableItem(csConfig.Hub, item)
 	if err != nil {
-		log.Fatalf("error while enabled %s : %v.", item.Name, err)
+		log.Fatalf("error while enabling  %s : %v.", item.Name, err)
 	}
 	cwhub.AddItem(obtype, item)
 	log.Infof("Enabled %s", item.Name)
@@ -169,7 +180,7 @@ func RemoveMany(itemType string, name string) {
 			log.Fatalf("unable to retrieve: %s", name)
 		}
 		item := *it
-		item, err = cwhub.DisableItem(csConfig.Cscli, item, purge, forceAction)
+		item, err = cwhub.DisableItem(csConfig.Hub, item, purge, forceAction)
 		if err != nil {
 			log.Fatalf("unable to disable %s : %v", item.Name, err)
 		}
@@ -177,7 +188,7 @@ func RemoveMany(itemType string, name string) {
 		return
 	} else if name == "" && all {
 		for _, v := range cwhub.GetItemMap(itemType) {
-			v, err = cwhub.DisableItem(csConfig.Cscli, v, purge, forceAction)
+			v, err = cwhub.DisableItem(csConfig.Hub, v, purge, forceAction)
 			if err != nil {
 				log.Fatalf("unable to disable %s : %v", v.Name, err)
 			}
@@ -201,26 +212,29 @@ func UpgradeConfig(itemType string, name string, force bool) {
 		if name != "" && name != v.Name {
 			continue
 		}
+
 		if !v.Installed {
 			log.Tracef("skip %s, not installed", v.Name)
-			if !force {
-				continue
-			}
+			continue
 		}
+
 		if !v.Downloaded {
 			log.Warningf("%s : not downloaded, please install.", v.Name)
-			if !force {
-				continue
-			}
+			continue
 		}
+
 		found = true
 		if v.UpToDate {
 			log.Infof("%s : up-to-date", v.Name)
+
 			if !force {
+				if err = cwhub.DownloadDataIfNeeded(csConfig.Hub, v, false); err != nil {
+					log.Fatalf("%s : download failed : %v", v.Name, err)
+				}
 				continue
 			}
 		}
-		v, err = cwhub.DownloadLatest(csConfig.Cscli, v, force)
+		v, err = cwhub.DownloadLatest(csConfig.Hub, v, force, true)
 		if err != nil {
 			log.Fatalf("%s : download failed : %v", v.Name, err)
 		}
@@ -265,7 +279,7 @@ func InspectItem(name string, objecitemType string) {
 	fmt.Printf("%s", string(buff))
 	if csConfig.Prometheus.Enabled {
 		if csConfig.Prometheus.ListenAddr == "" || csConfig.Prometheus.ListenPort == 0 {
-			log.Warningf("No prometheus address or port specified in '%s', can't show metrics", *csConfig.Self)
+			log.Warningf("No prometheus address or port specified in '%s', can't show metrics", *csConfig.FilePath)
 			return
 		}
 		if prometheusURL == "" {
@@ -328,6 +342,10 @@ func GetParserMetric(url string, itemName string) map[string]map[string]int {
 			source, ok := metric.Labels["source"]
 			if !ok {
 				log.Debugf("no source in Metric %v", metric.Labels)
+			} else {
+				if srctype, ok := metric.Labels["type"]; ok {
+					source = srctype + ":" + source
+				}
 			}
 			value := m.(prom2json.Metric).Value
 			fval, err := strconv.ParseFloat(value, 32)
@@ -501,7 +519,7 @@ func silenceInstallItem(name string, obtype string) (string, error) {
 	if downloadOnly && it.Downloaded && it.UpToDate {
 		return fmt.Sprintf("%s is already downloaded and up-to-date", it.Name), nil
 	}
-	it, err := cwhub.DownloadLatest(csConfig.Cscli, it, forceAction)
+	it, err := cwhub.DownloadLatest(csConfig.Hub, it, forceAction, false)
 	if err != nil {
 		return "", fmt.Errorf("error while downloading %s : %v", it.Name, err)
 	}
@@ -512,9 +530,9 @@ func silenceInstallItem(name string, obtype string) (string, error) {
 	if downloadOnly {
 		return fmt.Sprintf("Downloaded %s to %s", it.Name, csConfig.Cscli.HubDir+"/"+it.RemotePath), nil
 	}
-	it, err = cwhub.EnableItem(csConfig.Cscli, it)
+	it, err = cwhub.EnableItem(csConfig.Hub, it)
 	if err != nil {
-		return "", fmt.Errorf("error while enabled %s : %v", it.Name, err)
+		return "", fmt.Errorf("error while enabling %s : %v", it.Name, err)
 	}
 	if err := cwhub.AddItem(obtype, it); err != nil {
 		return "", err
@@ -525,6 +543,13 @@ func silenceInstallItem(name string, obtype string) (string, error) {
 func RestoreHub(dirPath string) error {
 	var err error
 
+	if err := csConfig.LoadHub(); err != nil {
+		return err
+	}
+	if err := setHubBranch(); err != nil {
+		return fmt.Errorf("error while setting hub branch: %s", err)
+	}
+
 	for _, itype := range cwhub.ItemTypes {
 		itemDirectory := fmt.Sprintf("%s/%s/", dirPath, itype)
 		if _, err = os.Stat(itemDirectory); err != nil {
