@@ -19,7 +19,7 @@ import (
 )
 
 //debugHandler is kept as a dev convenience : it shuts down and serialize internal state
-func debugHandler(sig os.Signal, cConfig *csconfig.GlobalConfig) error {
+func debugHandler(sig os.Signal, cConfig *csconfig.Config) error {
 	var tmpFile string
 	var err error
 	//stop go routines
@@ -37,32 +37,9 @@ func debugHandler(sig os.Signal, cConfig *csconfig.GlobalConfig) error {
 	return nil
 }
 
-func reloadHandler(sig os.Signal, cConfig *csconfig.GlobalConfig) error {
+func reloadHandler(sig os.Signal, cConfig *csconfig.Config) error {
 	var tmpFile string
 	var err error
-
-	//stop go routines
-	if !disableAgent {
-		if err := shutdownCrowdsec(); err != nil {
-			log.Fatalf("Failed to shut down crowdsec routines: %s", err)
-		}
-		if cConfig.Crowdsec != nil && cConfig.Crowdsec.BucketStateDumpDir != "" {
-			if tmpFile, err = leaky.DumpBucketsStateAt(time.Now(), cConfig.Crowdsec.BucketStateDumpDir, buckets); err != nil {
-				log.Fatalf("Failed dumping bucket state : %s", err)
-			}
-		}
-
-		if err := leaky.ShutdownAllBuckets(buckets); err != nil {
-			log.Fatalf("while shutting down routines : %s", err)
-		}
-	}
-
-	if !disableAPI {
-		if err := shutdownAPI(); err != nil {
-			log.Fatalf("Failed to shut down api routines: %s", err)
-		}
-	}
-
 	/*
 	 re-init tombs
 	*/
@@ -72,6 +49,12 @@ func reloadHandler(sig os.Signal, cConfig *csconfig.GlobalConfig) error {
 	outputsTomb = tomb.Tomb{}
 	apiTomb = tomb.Tomb{}
 	crowdsecTomb = tomb.Tomb{}
+	pluginTomb = tomb.Tomb{}
+
+	cConfig, err = csconfig.NewConfig(flags.ConfigFile, flags.DisableAgent, flags.DisableAPI)
+	if err != nil {
+		log.Fatalf(err.Error())
+	}
 
 	if err := LoadConfig(cConfig); err != nil {
 		log.Fatalf(err.Error())
@@ -81,7 +64,7 @@ func reloadHandler(sig os.Signal, cConfig *csconfig.GlobalConfig) error {
 		log.Fatal(err.Error())
 	}
 
-	if !disableAPI {
+	if !cConfig.DisableAPI {
 		apiServer, err := initAPIServer(cConfig)
 		if err != nil {
 			return fmt.Errorf("unable to init api server: %s", err)
@@ -90,7 +73,7 @@ func reloadHandler(sig os.Signal, cConfig *csconfig.GlobalConfig) error {
 		serveAPIServer(apiServer)
 	}
 
-	if !disableAgent {
+	if !cConfig.DisableAgent {
 		csParsers, err := initCrowdsec(cConfig)
 		if err != nil {
 			return fmt.Errorf("unable to init crowdsec: %s", err)
@@ -121,11 +104,13 @@ func ShutdownCrowdsecRoutines() error {
 	var reterr error
 
 	log.Debugf("Shutting down crowdsec sub-routines")
-	acquisTomb.Kill(nil)
-	log.Debugf("waiting for acquisition to finish")
-	if err := acquisTomb.Wait(); err != nil {
-		log.Warningf("Acquisition returned error : %s", err)
-		reterr = err
+	if len(dataSources) > 0 {
+		acquisTomb.Kill(nil)
+		log.Debugf("waiting for acquisition to finish")
+		if err := acquisTomb.Wait(); err != nil {
+			log.Warningf("Acquisition returned error : %s", err)
+			reterr = err
+		}
 	}
 	log.Debugf("acquisition is finished, wait for parser/bucket/ouputs.")
 	parsersTomb.Kill(nil)
@@ -175,18 +160,23 @@ func shutdownCrowdsec() error {
 	return nil
 }
 
-func termHandler(sig os.Signal) error {
-	if err := shutdownCrowdsec(); err != nil {
-		log.Errorf("Error encountered while shutting down crowdsec: %s", err)
+func shutdown(sig os.Signal, cConfig *csconfig.Config) error {
+	if !cConfig.DisableAgent {
+		if err := shutdownCrowdsec(); err != nil {
+			log.Errorf("Failed to shut down crowdsec: %s", err)
+			return err
+		}
 	}
-	if err := shutdownAPI(); err != nil {
-		log.Errorf("Error encountered while shutting down api: %s", err)
+	if !cConfig.DisableAPI {
+		if err := shutdownAPI(); err != nil {
+			log.Errorf("Failed to shut down api routines: %s", err)
+			return err
+		}
 	}
-	log.Debugf("termHandler done")
 	return nil
 }
 
-func HandleSignals(cConfig *csconfig.GlobalConfig) {
+func HandleSignals(cConfig *csconfig.Config) {
 	signalChan := make(chan os.Signal, 1)
 	signal.Notify(signalChan,
 		syscall.SIGHUP,
@@ -201,14 +191,17 @@ func HandleSignals(cConfig *csconfig.GlobalConfig) {
 			// kill -SIGHUP XXXX
 			case syscall.SIGHUP:
 				log.Warningf("SIGHUP received, reloading")
+				if err := shutdown(s, cConfig); err != nil {
+					log.Fatalf("failed shutdown : %s", err)
+				}
 				if err := reloadHandler(s, cConfig); err != nil {
 					log.Fatalf("Reload handler failure : %s", err)
 				}
 			// kill -SIGTERM XXXX
 			case syscall.SIGTERM:
 				log.Warningf("SIGTERM received, shutting down")
-				if err := termHandler(s); err != nil {
-					log.Fatalf("Term handler failure : %s", err)
+				if err := shutdown(s, cConfig); err != nil {
+					log.Fatalf("failed shutdown : %s", err)
 				}
 				exitChan <- 0
 			}
@@ -220,15 +213,15 @@ func HandleSignals(cConfig *csconfig.GlobalConfig) {
 	os.Exit(code)
 }
 
-func Serve(cConfig *csconfig.GlobalConfig) error {
+func Serve(cConfig *csconfig.Config) error {
 	acquisTomb = tomb.Tomb{}
 	parsersTomb = tomb.Tomb{}
 	bucketsTomb = tomb.Tomb{}
 	outputsTomb = tomb.Tomb{}
 	apiTomb = tomb.Tomb{}
 	crowdsecTomb = tomb.Tomb{}
-
-	if !disableAPI {
+	pluginTomb = tomb.Tomb{}
+	if !cConfig.DisableAPI {
 		apiServer, err := initAPIServer(cConfig)
 		if err != nil {
 			return errors.Wrap(err, "api server init")
@@ -238,7 +231,7 @@ func Serve(cConfig *csconfig.GlobalConfig) error {
 		}
 	}
 
-	if !disableAgent {
+	if !cConfig.DisableAgent {
 		csParsers, err := initCrowdsec(cConfig)
 		if err != nil {
 			return errors.Wrap(err, "crowdsec init")
@@ -250,6 +243,7 @@ func Serve(cConfig *csconfig.GlobalConfig) error {
 	}
 	if flags.TestMode {
 		log.Infof("test done")
+		pluginBroker.Kill()
 		os.Exit(0)
 	}
 
